# Configuration for VINCA
# currently there is only one variable! the fewer the better...
collection_path = '~/test.db'
